//------------------------------------------------------------------------------
// Lamp : Open source game middleware
// Copyright (C) 2004  Junpei Ohtani ( Email : junpee@users.sourceforge.jp )
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//------------------------------------------------------------------------------

/** @file
 * Lampテキストトランスレータヘッダ
 * @author Junpee
 */

#ifndef LAMP_TEXT_TRANSLATOR_H_
#define LAMP_TEXT_TRANSLATOR_H_

#include "Translator/Core/LampTranslator.h"

namespace LampForMaya{

//------------------------------------------------------------------------------
/**
 * Lampテキストトランスレータ
 */
class LampTextTranslator : public MPxFileTranslator{
public:
	/**
	 * コンストラクタ
	 */
	LampTextTranslator(){}

	/**
	 * デストラクタ
	 */
	virtual ~LampTextTranslator(){}

	/**
	 * 生成
	 *
	 * unloadPluginを行わないとメモリリークとして検出されます。
	 * @return プラグインインスタンス
	 */
	static void* creator(){ return new LampTextTranslator(); }

	/**
	 * 書き出し
	 * @param file ファイル名
	 * @param optionsString オプション
	 * @param mode ファイルアクセスモード
	 * @return 成功すれば MStatus::kSuccess
	 */
	virtual MStatus writer(const MFileObject& file,
		const MString& optionsString, FileAccessMode mode){
		LampTranslator translator;
		return translator.write(file, optionsString, mode, true);
	}

	/**
	 * 読み込み
	 * @param file ファイル名
	 * @param optionsString オプション
	 * @param mode ファイルアクセスモード
	 * @return 成功すれば MStatus::kSuccess
	 */
	virtual MStatus reader (const MFileObject& file,
		const MString& optionsString, FileAccessMode mode){
		return MStatus(MStatus::kFailure);
	}

	/**
	 * デフォルト拡張子
	 * @return デフォルト拡張子
	 */
	virtual MString defaultExtension() const{
		return LampTranslator::getTextSceneExtension().getBytes();
	}

	/**
	 * ファイルフィルタ
	 * @return ファイルフィルタ
	 */
	virtual MString filter() const{
		return MString("*.") + defaultExtension();
	}

	/**
	 * 書き込みメソッドを持つか
	 * @return 書き込みメソッドを持つならtrue
	 */
	virtual bool haveWriteMethod() const{ return true; }

	/**
	 * 読み込みメソッドを持つか
	 * @return 読み込みメソッドを持つならtrue
	 */
	virtual bool haveReadMethod() const{ return false; }

	/**
	 * ネームスペースをサポートするかどうか
	 * @return ネームスペースをサポートするならtrue
	 */
	virtual bool haveNamespaceSupport() const{ return false; }

	/**
	 * ファイルを開くことができるか
	 * @return ファイルを開けるならtrue
	 */
	virtual bool canBeOpened() const{ return false; }

	/**
	 * ファイルの識別
	 * @param file ファイルオブジェクト
	 * @param buffer ファイルバッファ
	 * @param size バッファサイズ
	 * @return ファイルが自らのファイルフォーマットかどうか
	 */
	virtual MPxFileTranslator::MFileKind identifyFile(
		const MFileObject& file, const char* buffer, short size) const{
		// 全て自分のフォーマットでない
		return kNotMyFileType;
	}


private:
	// コピーコンストラクタの隠蔽
	LampTextTranslator(const LampTextTranslator& copy);

	// 代入コピーの隠蔽
	void operator =(const LampTextTranslator& copy);

};

//------------------------------------------------------------------------------
} // End of namespace LampForMaya
#endif // End of LAMP_TEXT_TRANSLATOR_H_
//------------------------------------------------------------------------------
